ResponsivePreBuilderWith<T> typedef

ResponsivePreBuilderWith<T> = Widget Function(BuildContext context, Widget childBuilder(T param))

A function type for wrapping parameterized responsive widgets with additional functionality.

This typedef is used by ResponsiveWrapperWith to wrap the main responsive widget with additional widgets like state management providers or theme wrappers.

Parameters:

  • context: The build context
  • childBuilder: A function that creates a child widget when given a parameter of type T

Returns a widget that wraps the child with additional functionality.

Implementation

typedef ResponsivePreBuilderWith<T> =
    Widget Function(
      BuildContext context,
      Widget Function(T param) childBuilder,
    );